function [Triangles, Lengths, Angles, Areas, TotalArea, EigVal] = Octahedron(subdiv,const)
Triangles = [1 2 3; 1 2 4; 1 3 5; 1 4 5; 6 2 3; 6 2 4; 6 3 5; 6 4 5];
Angles = ones(8,3)*(pi/3);
Lengths = ones(8,3)*(const);

for i=1:subdiv
    EWNVs = [];
    tempTri = [];
    Edges = edgeSplitter(Triangles);
    for i=1:size(Edges,1)
        if Edges(i,1) > Edges(i,2)
            temp = Edges(i,1);
            Edges(i,1) = Edges(i,2);
            Edges(i,2) = temp;
        end
    end
    Edges = unique(Edges,'rows');
    newVs = zeros(size(Edges,1),1);
    edgeLength = Lengths(1,1);
    maxV = max(max(Triangles));
    for j=1:size(Triangles,1)
        idx1 = findRow(Edges,[Triangles(j,1) Triangles(j,2)]);
        if size(idx1,1) ~= 0
            if newVs(idx1,1) ~= 0
                tempV1 = newVs(idx1,1);
            else
                tempV1 = maxV + 1;
                newVs(idx1,1) = tempV1;
                maxV = tempV1;
            end
        else
            idx1 = findRow(Edges,[Triangles(j,2) Triangles(j,1)]);
            if newVs(idx1,1) ~= 0
                tempV1 = newVs(idx1,1);
            else
                tempV1 = maxV + 1;
                newVs(idx1,1) = tempV1;
                maxV = tempV1;
            end
        end
        idx2 = findRow(Edges,[Triangles(j,2) Triangles(j,3)]);
        if size(idx2,1) ~= 0
            if newVs(idx2,1) ~= 0
                tempV2 = newVs(idx2,1);
            else
                tempV2 = maxV + 1;
                newVs(idx2,1) = tempV2;
                maxV = tempV2;
            end
        else
            idx2 = findRow(Edges,[Triangles(j,3) Triangles(j,2)]);
            if newVs(idx2,1) ~= 0
                tempV2 = newVs(idx2,1);
            else
                tempV2 = maxV + 1;
                newVs(idx2,1) = tempV2;
                maxV = tempV2;
            end
        end
        idx3 = findRow(Edges,[Triangles(j,1) Triangles(j,3)]);
        if size(idx3,1) ~= 0
            if newVs(idx3,1) ~= 0
                tempV3 = newVs(idx3,1);
            else
                tempV3 = maxV + 1;
                newVs(idx3,1) = tempV3;
                maxV = tempV3;
            end
        else
            idx3 = findRow(Edges,[Triangles(j,3) Triangles(j,1)]);
            if newVs(idx3,1) ~= 0
                tempV3 = newVs(idx3,1);
            else
                tempV3 = maxV + 1;
                newVs(idx3,1) = tempV3;
                maxV = tempV3;
            end
        end
        newT1 = [Triangles(j,1) tempV1 tempV3];
        newT2 = [tempV1 Triangles(j,2) tempV2];
        newT3 = [tempV3 tempV2 Triangles(j,3)];
        newT4 = [tempV1 tempV2 tempV3];
        tempTri = [tempTri; newT1; newT2; newT3; newT4];
    end
    Triangles = tempTri;
    Lengths = ones(size(Triangles,1),3)*(edgeLength/2);
    Angles = ones(size(Triangles,1),3)*(pi/3);
end

Areas = zeros(size(Triangles,1),1);
for i=1:size(Triangles)
    semiP = sum(Lengths(i,1:3))/2;
    Areas(i,:) = sqrt(semiP*(semiP-Lengths(i,1))*(semiP-Lengths(i,2))*(semiP-Lengths(i,3)));
end
TotalArea = sum(Areas);
lastVVal = max(max(Triangles));

energyMatrix = zeros(lastVVal,lastVVal);
gramMatrix = zeros(lastVVal,lastVVal);

for i=1:size(Triangles,1)
    tempV1 = Triangles(i,1);
    tempV2 = Triangles(i,2);
    tempV3 = Triangles(i,3);
    gramMatrix(tempV1,tempV1) = gramMatrix(tempV1,tempV1) + 1/6*Areas(i,:);
    gramMatrix(tempV2,tempV2) = gramMatrix(tempV2,tempV2) + 1/6*Areas(i,:);
    gramMatrix(tempV3,tempV3) = gramMatrix(tempV3,tempV3) + 1/6*Areas(i,:);
    gramMatrix(tempV1,tempV2) = gramMatrix(tempV1,tempV2) + 1/12*Areas(i,:);
    gramMatrix(tempV2,tempV3) = gramMatrix(tempV2,tempV3) + 1/12*Areas(i,:);
    gramMatrix(tempV3,tempV1) = gramMatrix(tempV3,tempV1) + 1/12*Areas(i,:);
    
    gramMatrix(tempV2,tempV1) = gramMatrix(tempV2,tempV1) + 1/12*Areas(i,:);
    gramMatrix(tempV3,tempV2) = gramMatrix(tempV3,tempV2) + 1/12*Areas(i,:);
    gramMatrix(tempV1,tempV3) = gramMatrix(tempV1,tempV3) + 1/12*Areas(i,:);
    

    energyMatrix(tempV1,tempV1) = energyMatrix(tempV1,tempV1) + (Lengths(i,1)^2)/(4*Areas(i,:));
    energyMatrix(tempV2,tempV2) = energyMatrix(tempV2,tempV2) + (Lengths(i,2)^2)/(4*Areas(i,:));
    energyMatrix(tempV3,tempV3) = energyMatrix(tempV3,tempV3) + (Lengths(i,3)^2)/(4*Areas(i,:));
    energyMatrix(tempV1,tempV2) = energyMatrix(tempV1,tempV2) - (1/2)*cot(Angles(i,3));
    energyMatrix(tempV2,tempV3) = energyMatrix(tempV2,tempV3) - (1/2)*cot(Angles(i,1));
    energyMatrix(tempV3,tempV1) = energyMatrix(tempV3,tempV1) - (1/2)*cot(Angles(i,2));
        
    energyMatrix(tempV2,tempV1) = energyMatrix(tempV2,tempV1) - (1/2)*cot(Angles(i,3));
    energyMatrix(tempV3,tempV2) = energyMatrix(tempV3,tempV2) - (1/2)*cot(Angles(i,1));
    energyMatrix(tempV1,tempV3) = energyMatrix(tempV1,tempV3) - (1/2)*cot(Angles(i,2));
end
gramMatrix(all(~gramMatrix,2),:) = [];
gramMatrix(:,all(~gramMatrix,1)) = [];


energyMatrix(all(~energyMatrix,2),:) = [];
energyMatrix(:,all(~energyMatrix,1)) = [];

EigVal = eig(energyMatrix,gramMatrix);

end

