function [labels1,labels2] = XangleMatching(m)
%X - improved version / 500x faster at level 8
%angleMatching - at level m, this function matches all the angles on the
%  SG with their subsequent a-values, and thus "fills" our SG. To be more
%  precise, labels1(i) >> A(i) and labels2(i) >> A2(i).
%  T >> A | T2 >> A2
%  T and T2 are temporary matrices that contain the addresses of the
%  vertices on the outer edges at a particular point in the iteration.
tic
labels1=zeros(sizeofA(m),1);
labels2=zeros(sizeofA(m),1);

%Counts up in binary. %T(i) = i-1 expressed in binary with each number in
%  a separate cell. Adds a column of zeros to adjust for level m
T = dec2bin(0:(2^(m)-1)) - '0';
T = [zeros(size(T,1),1) T];
T2=2*T;

[A,A2] = XbinaryNames(m);
aValues = recFinal(m);

[labels1, labels2] = XlabelMatching(A,A2,aValues,T,T2,labels1,labels2);

%FOR LOOP matches angles with their subsequent value on the top
%  third of the SG. The filling is done by moving on inside "outer" edges
%  (that are smaller) on each iteration. The smaller the inside edges, 
%  the more numerous they will be.
for i=1:(m-1)
    tempT = T(2:size(T,1)/2^(i),:);
    tempT2 = T2(2:size(T2,1)/2^(i),:);
    tempT(:,i+1) = 2;
    tempT2(:,i+1) = 1;

    saV = size(aValues,1);
    initLoc = saV - (saV/2^i) + 2;
    tempaVal = aValues(initLoc:saV,:);

    if i==1
        [labels1, labels2] = XlabelMatching(A,A2,tempaVal,tempT,tempT2,labels1,labels2);
    else
        %Comb = unique(nchoosek(repmat([0,1,2], 1,i-1), i-1), 'rows');
        Comb = dec2base(0:(3^(i-1)-1),3,i-1) - '0';
        %Counting up in tertiary
        for j=1:size(Comb,1)
            toReplace = repmat(Comb(j,:),size(tempT,1),1);
            tempT(:,2:size(Comb,2)+1)= toReplace;
            tempT2(:,2:size(Comb,2)+1)= toReplace;
            [labels1, labels2] = XlabelMatching(A,A2,tempaVal,tempT,tempT2,labels1,labels2);
            %BOTTLENECK
        end
    end
end

newlabels1 = labels1;
newlabels2 = labels2;

%FOR LOOP takes the values on the top third of the SG and rotates them with
%  A+1 (mod) 3 and A+2 (mod) 3 in order to fill in the remaining 2 bottom parts
%  of the SG.
soA = sizeofA(m-1);
tempA = A(1:soA,:);
tempA2 = A2(1:soA,:);
for i=1:2
    newA = mod(tempA + i,3);
    newA2 = mod(tempA2 + i,3);
    for j=1:soA
        index = findRow(A,newA(j,:));
        if ~isnan(index)
            newlabels1(index,:) = labels1(j,:);
        else
            index  = findRow(A2,newA(j,:));
            newlabels2(index,:) = labels1(j,:);
        end
        if labels2(j,:) ~= 0
            index = findRow(A2,newA2(j,:));
            if ~isnan(index)
                newlabels2(index,:) = labels2(j,:);
            else
                index = findRow(A,newA2(j,:));
                newlabels1(index,:) = labels2(j,:);
            end
        end     
    end    
end

labels1 = newlabels1;
labels2 = newlabels2;

toc
end