function [A, A2] = XbinaryNames(m)
%X - improved version / at least 10x faster
%binaryNames - at level m, this function returns matrices
%  A and A2 which contain the vertex - angle addresses
%  for all vertices in the curved face. We have A and A2 because,
%  all vertices are related to 2 angles in the gasket, the only 
%  3 exceptions being the corners. A(i) stores one angle value of
%  vertex i while A2(i) stores the other one.
%  A(i) = vertex address

tic
A(1,1:2)=[0 0];
A(2,1:2)=[0 1];
A(3,1:2)=[0 2];
A(4,1:2)=[1 1];
A(5,1:2)=[1 2];
A(6,1:2)=[2 2];

A2(1,1:2)=[0 0];
A2(2,1:2)=[1 0];
A2(3,1:2)=[2 0];
A2(4,1:2)=[1 1];
A2(5,1:2)=[2 1];
A2(6,1:2)=[2 2];

for i = 2:m
   rA = size(A,1);  %Rows of A
   cA = size(A,2);  %Columns of A
   
   %Enlarge i+1 level based on i level of A
   Atemp(3*rA, cA+1) = 0;
   Atemp(1:rA, 2:cA+1) = A;
   Atemp(1:rA, 1) = 0;
   Atemp(rA+1:2*rA, 2:cA+1) = A;
   Atemp(rA+1:2*rA, 1) = 1;
   Atemp(2*rA+1:3*rA, 2:cA+1) = A;
   Atemp(2*rA+1:3*rA, 1) = 2;
   A = Atemp;
   
   rA2 = size(A2,1);
   cA2 = size(A2,2);
   
   A2temp(3*rA2, cA2+1) = 0;
   A2temp(1:rA2, 2:cA2+1) = A2;
   A2temp(1:rA2, 1) = 0;
   A2temp(rA2+1:2*rA2, 2:cA2+1) = A2;
   A2temp(rA2+1:2*rA2, 1) = 1;
   A2temp(2*rA2+1:3*rA2, 2:cA2+1) = A2;
   A2temp(2*rA2+1:3*rA2, 1) = 2;
   A2 = A2temp;
   
   %c stores the locations of the 6 spots where A and A2 differ
   c = zeros(1,6);
   %delete redundant rows in new As
   A = [A(1:rA,:); A((rA+2):(2*rA-1),:); A((2*rA+2):3*rA,:)];
   A2 = [A2(1:rA2,:); A2((rA2+2):(2*rA2-1),:); A2((2*rA2+2):3*rA2,:)];
   %determine locations of those spots
   for j = 1:size(A,1)
       if A(j,:) == A2(j,:)
           c(j)=j;
       else
           c(j)=0;
       end
   end
   
   c(c==0) = []; %delete non-zero elements
   A2(c(2),:)=0;
   A2(c(3),:)=0;
   A2(c(5),:)=2;
   A2(c(2),1)=1;
   A2(c(3),1)=2;
   A2(c(5),1)=1;
   %c seems to only have 6 values at any level
   %so this hard-coding works
end
toc
end