function [A, A2] = XbinaryNamesXNC(m)
%X - improved version / at least 10x faster
%XNC - New Construction idea / might be significantly faster
%binaryNames - at level m, this function returns matrices
%  A and A2 which contain the vertex - angle addresses
%  for all vertices in the curved face. We have A and A2 because,
%  all vertices are related to 2 angles in the gasket, the only 
%  3 exceptions being the corners. A(i) stores one angle value of
%  vertex i while A2(i) stores the other one.
%  A(i) = vertex address 
%  ORDER of A - A2 pairs might not matter in terms of indexing
%  A - A2 is IMPORTANT

tic
Core(1,1:2)=[0 1];
Core(2,1:2)=[0 2];
Core(3,1:2)=[1 2];
A = [0 0; Core; 1 1; 2 2];
Core2(1,1:2)=[1 0];
Core2(2,1:2)=[2 0];
Core2(3,1:2)=[2 1];
A2 = [0 0; Core2; 1 1; 2 2];

for i = 2:m
   rCore = size(Core,1);  %Rows of Core
   cCore = size(Core,2);  %Columns of Core
   
   zVec = zeros(rCore,1);
   oVec = zVec + 1;
   tVec = zVec + 2;
   
   horZ = zeros(1,i);
   LMV = [0 horZ+1];
   BMV = [1 horZ+2];
   RMV = [2 horZ];
   
   LMV2 = [1 horZ];
   BMV2 = [2 horZ+1];
   RMV2 = [0 horZ+2];
   
   zCore = [zVec Core];
   zCore = [zCore; LMV];
   oCore = [oVec Core];
   oCore = [oCore; BMV];
   tCore = [tVec Core];
   tCore = [tCore; RMV];
   
   zCore2 = [zVec Core2];
   zCore2 = [zCore2; LMV2];
   oCore2 = [oVec Core2];
   oCore2 = [oCore2; BMV2];
   tCore2 = [tVec Core2];
   tCore2 = [tCore2; RMV2];
   
   Core = [zCore; oCore; tCore];
   Core2 = [zCore2; oCore2; tCore2];
end

if (m > 1)
    zCorner = zeros(1,m+1);
    oCorner = zeros(1,m+1)+1;
    tCorner = zeros(1,m+1)+2;
    Corners = [zCorner; oCorner; tCorner];

    A = [Corners; Core];
    A2 = [Corners; Core2];
end

toc
end