function [Tri,Angles,SinActualAngles,A,A2,labels1,labels2] = XtriangleCreator(m)
%X - improved version / 200x faster at level 7
%triangleCreator - at level m, this function uses labels1(i) >> A(i) as 
%  well as labels2(i) >> A2(i) to create two n-by-3 matrices, Tri and Angles.
%  Tri(i) holds the vertex labels of the ith triangle 
%  Angles(i) holds the corresponding angle values of those particular
%  vertices for the angle that is in that particular trinagle.
tic
comb = dec2base(0:(3^(m+1)-1),3,m+1) - '0';

%Pre-allocation of to-be-filled matrices
Tri = zeros (3^m,3);
Angles = zeros (3^m,3);

[A,A2] = XbinaryNames(m);
[labels1,labels2] = XangleMatching(m);

%FOR LOOP searches for an index value in A or A2 from comb. It uses that
%  index value as a vertex label for the Tri matrix. Thus the index of an
%  entry in A or A2 will become that particular vertex's label.
%  NOTE that the searching is done in order from 0 to 3^(m+1)-1 and we will
%  successfully go through all vertices in all triangles properly.
cnt = 0;
for i=1:3:size(comb,1)
    cnt = cnt + 1;
    for j=0:2
        idx = findRow(A, comb(i+j,:));
        if ~isnan(idx)
            Tri(cnt,j+1) = idx;
            Angles(cnt,j+1) = labels1(idx);
        else
            idx = findRow(A2, comb(i+j,:));
            Tri(cnt,j+1) = idx;
            Angles(cnt,j+1) = labels2(idx);
        end
    end 
end

%This extra output was formerly computer by Sin.m but was introduced here
%  for continuity.
SinActualAngles = sin(pi/3 + Angles*(pi/(3^(m+1))));
toc
end